@@ -6,7 +6,7 @@ pub mod tools;
 mod conv_test {
     use basic_dsp::conv_types::*;
     use basic_dsp::*;
-    use tools::*;
+    use crate::tools::*;
 
     #[test]
     fn compare_conv_freq_multiplication_for_rc() {
@@ -32,7 +32,7 @@ mod conv_test {
             assert_vector_eq_with_reason_and_tolerance(
                 &ifreq_res[..],
                 &time[..],
-                0.2,
+                0.3,
                 "Results should match independent if done \
                  in time or frequency domain",
             );
